import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  scaleOrdinal,
  schemeCategory10,
  behavior
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { scatterplot } from './scatterplot';
import { dropdownMenu } from './dropdownMenu';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const colorLegendG = svg.append('g');

const color = scaleOrdinal(schemeCategory10);

let selectedCategory = null;
let menuItems;
let xColumn;
let yColumn;

const colorValue = data => data.Category;

const onClick = d => {
  selectedCategory = d;
  render();
};

loadAndProcessData().then(data => {
  menuItems = data;
  xColumn = data.columns[3];
  yColumn = data.columns[19];
  render();
});

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

// tooltip mouseover event handler
var tipMouseover = function (d) {
  var html = d.Item + "<br/>" +
    "<span style='color:" + color(colorValue(d)) + ";'>" + d.Category + "</span><br/>" +
    "<b>" + d[xColumn] + `</b> ${xColumn}, <b/>` + d[yColumn] + `</b> ${yColumn}`;
  select('.tooltip').html(html)
    .style("left", (d3.event.pageX + 15) + "px")
    .style("top", (d3.event.pageY - 28) + "px")
    .transition()
    .duration(200) // ms
    .style("opacity", .9) // started as 0!
};
// tooltip mouseout event handler
var tipMouseout = function (d) {
  select('.tooltip').transition()
    .duration(300) // ms
    .style("opacity", 0);
};

const render = () => {

  select('#x-menu')
    .call(dropdownMenu, {
      options: menuItems.columns.filter(column =>
        column !== 'Item' &&
        column !== 'Category'
      ),
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });

  select('#y-menu')
    .call(dropdownMenu, {
      options: menuItems.columns,
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });

  svg.call(scatterplot, {
    xAxisLabel: xColumn,
    yAxisLabel: yColumn,
    xValue: d => d[xColumn],
    yValue: d => d[yColumn],
    circleRadius: 10,
    margin: { top: 10, right: 185, bottom: 88, left: 150 },
    width,
    height,
    data: menuItems,
    color,
    colorValue,
    selectedCategory,
    tipMouseover,
    tipMouseout
  });


  svg.call(colorLegend, {
    color,
    width,
    selectedCategory,
    onClick
  });

  select('body').append("div")
    .attr("class", "tooltip")
    .style("opacity", 0);
  
};